==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/CursedDecoyDollItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.npc.NPCRoleEntityImpl;
import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1531;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3222;

public class CursedDecoyDollItem extends class_1792 {
    public CursedDecoyDollItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1657 player = context.method_8036();
        class_1268 hand = context.method_20287();
        class_1937 world = context.method_8045();
        class_2338 blockPos = context.method_8037().method_10084();
        if (!world.field_9236 && world instanceof class_3218 serverWorld && player instanceof class_3222 serverPlayer) {
            class_1799 stackInHand = serverPlayer.method_5998(hand);
            class_1531 armorStandEntity = new class_1531(serverWorld, blockPos.method_10263() + 0.5, blockPos.method_10264() + 0.5, blockPos.method_10260() + 0.5);
            armorStandEntity.method_36456(player.method_36454());
            armorStandEntity.method_36457(player.method_36455());
            serverWorld.method_8649(armorStandEntity);
            List<class_1309> list = world.method_8390(class_1309.class, new class_238(blockPos).method_1014(24), livingEntity -> true);
            for (class_1309 livingEntity : list) {
                if (livingEntity instanceof class_1657) continue;
                if (livingEntity instanceof NPCRoleEntityImpl role) {
                    class_1309 attacker = role.method_6065();
                    class_1309 target = role.method_5968();
                    if (attacker == player || target == player) {
                        continue;
                    }
                }
                if (livingEntity instanceof class_1308 mob) {
                    if (mob.method_5968() != null) {
                        mob.method_5980(armorStandEntity);
                    }
                }
                if (livingEntity.method_6065() != null) {
                    livingEntity.method_6015(armorStandEntity);
                }
            }
            stackInHand.method_57008(1, serverPlayer);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/CursedDecoyDollItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.npc.NPCRoleEntity;
import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1531;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3222;

public class CursedDecoyDollItem extends class_1792 {
    public CursedDecoyDollItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1657 player = context.method_8036();
        class_1268 hand = context.method_20287();
        class_1937 world = context.method_8045();
        class_2338 blockPos = context.method_8037().method_10084();
        if (!world.field_9236 && world instanceof class_3218 serverWorld && player instanceof class_3222 serverPlayer) {
            class_1799 stackInHand = serverPlayer.method_5998(hand);
            class_1531 armorStandEntity = new class_1531(serverWorld, blockPos.method_10263() + 0.5, blockPos.method_10264() + 0.5, blockPos.method_10260() + 0.5);
            armorStandEntity.method_36456(player.method_36454());
            armorStandEntity.method_36457(player.method_36455());
            serverWorld.method_8649(armorStandEntity);
            List<class_1309> list = world.method_8390(class_1309.class, new class_238(blockPos).method_1014(24), livingEntity -> true);
            for (class_1309 livingEntity : list) {
                if (livingEntity instanceof class_1657) continue;
                if (livingEntity instanceof NPCRoleEntity role) {
                    class_1309 attacker = role.method_6065();
                    class_1309 target = role.method_5968();
                    if (attacker == player || target == player) {
                        continue;
                    }
                }
                if (livingEntity instanceof class_1308 mob) {
                    if (mob.method_5968() != null) {
                        mob.method_5980(armorStandEntity);
                    }
                }
                if (livingEntity.method_6065() != null) {
                    livingEntity.method_6015(armorStandEntity);
                }
            }
            stackInHand.method_57008(1, serverPlayer);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
